..
    Copyright (C) 2022 CERN.

    Invenio-Users-Resources is free software; you can redistribute it
    and/or modify it under the terms of the MIT License; see LICENSE file for
    more details.

Authors
=======

Invenio module providing management APIs for users and roles/groups.

- CERN <info@inveniosoftware.org>
- TU Wien <tudata@tuwien.ac.at>
- KTH Royal Institute of Technology <info@kth.se>
